@@ -9,6 +9,7 @@ class ArtifactEmulator:
         self._artifacts_by_id = {}
         self._files = {}
         self._base_url = base_url
+        self._portfolio_links = {}
 
     def create(self, variables):
         collection_name = variables["artifactCollectionNames"][0]
@@ -60,6 +61,26 @@ class ArtifactEmulator:
 
         return response
 
+    def link(self, variables):
+        pfolio_name = variables.get("artifactPortfolioName")
+        artifact_id = variables.get("artifactID") or variables.get("clientID")
+        if not pfolio_name or not artifact_id:
+            raise ValueError(
+                "query variables must contain artifactPortfolioName and either artifactID or clientID"
+            )
+        aliases = variables.get("aliases")
+        # We automatically create a portfolio for the user if we can't find the one given.
+        links = self._portfolio_links.setdefault(pfolio_name, [])
+        if not any(map(lambda x: x["id"] == artifact_id, links)):
+            art = {"id": artifact_id, "aliases": [a["alias"] for a in aliases]}
+            links.append(art)
+
+        self._ctx["portfolio_links"].setdefault(pfolio_name, {})
+        num = len(links)
+        self._ctx["portfolio_links"][pfolio_name]["num"] = num
+        response = {"data": {"linkArtifact": {"versionIndex": num - 1}}}
+        return response
+
     def create_files(self, variables):
         base_url = self._base_url
         response = {
@@ -87,11 +108,15 @@ class ArtifactEmulator:
 
     def query(self, variables, query=None):
         public_api_query_str = "query Artifact($id: ID!) {"
+        public_api_query_str2 = "query ArtifactWithCurrentManifest($id: ID!) {"
         art_id = variables.get("id")
         art_name = variables.get("name")
         assert art_id or art_name
 
-        is_public_api_query = query and query.startswith(public_api_query_str)
+        is_public_api_query = query and (
+            query.startswith(public_api_query_str)
+            or query.startswith(public_api_query_str2)
+        )
 
         if art_name:
             collection_name, version = art_name.split(":", 1)
